<div class="navbar navbar-fixed-top">
 <div class="navbar-inner">
  <div class="container-fluid">
   <a data-target=".nav-collapse" data-toggle="collapse" class="btn btn-navbar">
    <span class="icon-bar"></span>
    <span class="icon-bar"></span>
    <span class="icon-bar"></span>
   </a>
   <a href="/" class="brand">LISA Dashboard</a>
   <div class="nav-collapse">
       <ul class="nav pull-left">
           <li class>
               <a href="/speech">Speech</a>
           </li>
           <li class="divider-vertical" />
           <li class>
               <a href="/plugins/list">Plugins</a>
           </li>
           <li class>
               <a href="/plugins/list">Intents</a>
           </li>
       </ul>
    <ul class="nav pull-right">
     <li id="menu1" class="dropdown">
      <a href="#" data-toggle="dropdown" class="dropdown-toggle">lisa<b class="caret"></b></a>
      <ul class="dropdown-menu">
          <li><a href="https://lisa.readthedocs.org/en/latest/" target="_blank"><i class="icon-book icon-white"></i> Documentation</a></li>
          <li><a href="https://github.com/Seraf/LISA/issues?state=open" target="_blank"><i class="icon-bug icon-white"></i> Feedback</a></li>
          <li><a href="mailto:contact@lisa-project.net"><i class="icon-envelope icon-white"></i> Contact us</a></li>
          <li><a href="/logout"><i class="icon-off icon-white"></i> Log Out</a></li>
      </ul>
     </li>
    </ul>
   </div><!--/.nav-collapse -->
  </div>
 </div>
</div>
